summaryrefslogtreecommitdiffstats
path: root/kolf/kcomboboxdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kolf/kcomboboxdialog.h')
-rw-r--r--kolf/kcomboboxdialog.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kolf/kcomboboxdialog.h b/kolf/kcomboboxdialog.h
index e835c0aa..fdd74840 100644
--- a/kolf/kcomboboxdialog.h
+++ b/kolf/kcomboboxdialog.h
@@ -25,7 +25,7 @@
#ifndef KCOMBOBOX_DIALOG_H
#define KCOMBOBOX_DIALOG_H
-#include <qstringlist.h>
+#include <tqstringlist.h>
#include <kdialogbase.h>
#include <kglobal.h>
@@ -34,7 +34,7 @@ class QCheckBox;
class KHistoryCombo;
/**
* Dialog for user to choose an item from a QStringList.
*/
class KComboBoxDialog : public KDialogBase
@@ -51,13 +51,13 @@ public:
* @param _text Text of the label
* @param _value Initial value of the combobox
*/
- KComboBoxDialog( const QString &_text, const QStringList& _items, const QString& _value = QString::null, bool showDontAskAgain = false, QWidget *parent = 0 );
+ KComboBoxDialog( const TQString &_text, const TQStringList& _items, const TQString& _value = TQString::null, bool showDontAskAgain = false, TQWidget *parent = 0 );
virtual ~KComboBoxDialog();
/**
* @return the value the user chose
*/
- QString text() const;
+ TQString text() const;
/**
* @return the line edit widget
@@ -70,9 +70,9 @@ public:
* @param _text Text of the label
* @param _items Items in the combobox
* @param _value Initial value of the inputline
* @param dontAskAgainName Name for saving whether the user doesn't want to be asked again; use QString::null to disable
*/
- static QString getItem( const QString &_text, const QStringList &_items, const QString& _value = QString::null, const QString &dontAskAgainName = QString::null, QWidget *parent = 0 );
+ static TQString getItem( const TQString &_text, const TQStringList &_items, const TQString& _value = TQString::null, const TQString &dontAskAgainName = TQString::null, TQWidget *parent = 0 );
/**
* Static convenience function to get input from the user.
@@ -82,9 +82,9 @@ public:
* @param _text Text of the label
* @param _items Items in the combobox
* @param _value Initial value of the inputline
* @param dontAskAgainName Name for saving whether the user doesn't want to be asked again; use QString::null to disable
*/
- static QString getItem( const QString &_text, const QString &_caption, const QStringList &_items, const QString& _value = QString::null, const QString &dontAskAgainName = QString::null, QWidget *parent = 0 );
+ static TQString getItem( const TQString &_text, const TQString &_caption, const TQStringList &_items, const TQString& _value = TQString::null, const TQString &dontAskAgainName = TQString::null, TQWidget *parent = 0 );
/**
* Static convenience method.
@@ -99,15 +99,15 @@ public:
* @param configName Name of the dialog for saving the completion and history
* @parma config KConfig for saving the completion and history
*/
- static QString getText(const QString &_caption, const QString &_text,
- const QString &_value = QString::null,
- bool *ok = 0, QWidget *parent = 0,
- const QString &configName = QString::null,
+ static TQString getText(const TQString &_caption, const TQString &_text,
+ const TQString &_value = TQString::null,
+ bool *ok = 0, TQWidget *parent = 0,
+ const TQString &configName = TQString::null,
KConfig *config = KGlobal::config());
protected:
KHistoryCombo *combo;
- QCheckBox *dontAskAgainCheckBox;
+ TQCheckBox *dontAskAgainCheckBox;
bool dontAskAgainChecked();
};
@@ -34,7 +34,7 @@ class QCheckBox;
class KHistoryCombo;
/**
- * Dialog for user to choose an item from a QStringList.
+ * Dialog for user to choose an item from a TQStringList.
*/
class KComboBoxDialog : public KDialogBase
@@ -70,9 +70,9 @@ public:
* @param _items Items in the combobox
* @param _value Initial value of the inputline
- * @param dontAskAgainName Name for saving whether the user doesn't want to be asked again; use QString::null to disable
+ * @param dontAskAgainName Name for saving whether the user doesn't want to be asked again; use TQString::null to disable
*/
@@ -82,9 +82,9 @@ public:
* @param _items Items in the combobox
* @param _value Initial value of the inputline
- * @param dontAskAgainName Name for saving whether the user doesn't want to be asked again; use QString::null to disable
+ * @param dontAskAgainName Name for saving whether the user doesn't want to be asked again; use TQString::null to disable
*/